DROP TABLE studenci;
DROP TABLE miejscowosci;

------------------------------------------------------------
-- Wersja z jawnie zdefiniowanymi nazwami ogranicze
------------------------------------------------------------
CREATE TABLE studenci (
	stud_id        NUMBER        NOT NULL,
	miejscowosc_id NUMBER        NOT NULL,
	imie           VARCHAR2 (30) NOT NULL,
	nazwisko       VARCHAR2 (30) NOT NULL,
	pesel          NUMBER (11,0) NOT NULL,
	plec           CHAR (1)      NOT NULL, 
	stypendium     NUMBER (8,2)  DEFAULT 0 NOT NULL,
	uwagi          VARCHAR2 (100),
	CONSTRAINT studenci_pk PRIMARY KEY (stud_id), 
	CONSTRAINT studenci_plec_ck CHECK (plec IN ('K', 'M')),
	CONSTRAINT studenci_pesel_uq UNIQUE (pesel)
);

CREATE TABLE miejscowosci (
	miejscowosc_id NUMBER NOT NULL,
	nazwa          VARCHAR2 (30),
	CONSTRAINT miejscowosci_pk PRIMARY KEY (miejscowosc_id),
	CONSTRAINT miejscowosci_nazwa_uq UNIQUE (nazwa)	
);

ALTER TABLE studenci 
	ADD CONSTRAINT miejscowosci_studenci_fk 
	FOREIGN KEY (miejscowosc_id) 
	REFERENCES miejscowosci (miejscowosc_id);

	
------------------------------------------------------------
-- Wersja BEZ jawnie zdefiniowanych nazw ogranicze
------------------------------------------------------------	

CREATE TABLE studenci (
	stud_id        NUMBER        NOT NULL PRIMARY KEY,
	miejscowosc_id NUMBER        NOT NULL,
	imie           VARCHAR2 (30) NOT NULL,
	nazwisko       VARCHAR2 (30) NOT NULL,
	pesel          NUMBER (11,0) NOT NULL UNIQUE,
	plec           CHAR (1)      NOT NULL CHECK (plec IN ('K', 'M')), 
	stypendium     NUMBER (8,2)  DEFAULT 0 NOT NULL,
	uwagi          VARCHAR2 (100)
);

CREATE TABLE miejscowosci (
	miejscowosc_id NUMBER NOT NULL PRIMARY KEY,
	nazwa          VARCHAR2 (30) UNIQUE
);

ALTER TABLE studenci 
	ADD FOREIGN KEY (miejscowosc_id) 
	REFERENCES miejscowosci (miejscowosc_id);
	
------------------------------------------------------------
-- Wywietlamy ograniczenia 
------------------------------------------------------------		
SELECT 
	constraint_name, 
	constraint_type, 
	table_name, 
	search_condition, 
	r_constraint_name 
FROM 
	user_constraints 
WHERE 
	table_name IN ('STUDENCI', 'MIEJSCOWOSCI');
	

INSERT INTO miejscowosci VALUES (1, 'Zielona Gra');
INSERT INTO studenci VALUES (1, 1, 'Artur', 'Gramacki', '99999999999', 'M', 0, NULL);
COMMIT;

-- Naruszenie ograniczenia PK
INSERT INTO miejscowosci VALUES (1, 'Wrocaw');
-- Naruszenie ograniczenia CK
INSERT INTO studenci VALUES (2, 1, 'Artur', 'Gramacki', '99999999999', 'X', 0, NULL);
-- Naruszenie ograniczenia UQ
INSERT INTO studenci VALUES (2, 1, 'Artur', 'Gramacki', '99999999999', 'M', 0, NULL);
-- Naruszenie ograniczenia FK
INSERT INTO studenci VALUES (2, 3, 'Artur', 'Gramacki', '11111111111', 'M', 0, NULL);
-- Naruszenie ograniczenia NN
INSERT INTO studenci VALUES (2, 1, NULL, NULL, '11111111111', 'M', 0, NULL);


